Example Settings File
=====================

Below is a copy of the example settings file that you can find in the source
distribution in the folder "example".

.. include:: ../tests/examples/settings.py
   :code: python
